@@ -19,28 +19,31 @@ class Meter(object):
     Attributes:
         email: A string representing the email address of the account
         password: A string representing the password of the account
-        mfa_aswer: A string representing the multiple factor authorization answer for the account
+        mfa_answer: A string representing the multiple factor authorization answer for the account
         account_id: A string representing the account's id
         meter_id: A string representing the meter's id
     """
 
-    def __init__(self, email, password, mfa_aswer, account_id, meter_id, loop=None):
+    def __init__(self, email, password, mfa_answer, account_id, meter_id, loop=None):
         """Return a meter object whose meter id is *meter_id*"""
         self.email = email
         self.password = password
-        self.mfa_aswer = mfa_aswer
+        self.mfa_answer = mfa_answer
         self.account_id = account_id
         self.meter_id = meter_id
-        self.unit_of_measurement = 'WH'
         self.loop = loop
+        # _LOGGER.debug("Oru email = %s", self.email.replace(self.email[:10], '*'))
+        # _LOGGER.debug("Oru password = %s", self.password.replace(self.password[:9], '*'))
+        # _LOGGER.debug("Oru mfa_answer = %s", self.mfa_answer.replace(self.mfa_answer[:8], '*'))
+        # _LOGGER.debug("Oru account_id = %s", self.account_id.replace(self.account_id[:20], '*'))
+        # _LOGGER.debug("Oru meter_id = %s", self.meter_id.replace(self.meter_id[:5], '*'))
 
-    def last_read(self):
-        """Return the last meter read in WH"""
+    async def last_read(self):
+        """Return the last meter read value and unit of measurement"""
         try:
-            if self.loop is None:
-                asyncio.get_event_loop().run_until_complete(self.browse())
-            else:
-                asyncio.ensure_future(self.browse())
+            asyncio.set_event_loop(self.loop)
+            asyncio.create_task(self.browse())
+            await self.browse()
 
             # parse the return reads and extract the most recent one
             # (i.e. last not None)
@@ -52,20 +55,27 @@ class Meter(object):
                 lastRead = read
             _LOGGER.debug("lastRead = %s", lastRead)
 
-            self.last_read_wh = lastRead['value']
+            self.last_read_val = lastRead['value']
             self.unit_of_measurement = jsonResponse['unit']
 
-            _LOGGER.debug("val = %s %s", self.last_read, self.unit_of_measurement)
+            _LOGGER.debug("last read = %s %s", self.last_read_val, self.unit_of_measurement)
 
-            return self.last_read_wh
-        except requests.exceptions.RequestException:
+            return self.last_read_val, self.unit_of_measurement
+        except:
             raise MeterError("Error requesting meter data")
 
     async def browse(self):
-        browser = await launch({"defaultViewport": {"width": 1920, "height": 1080}, "dumpio": True})
+        browser = await launch({
+            "defaultViewport": {"width": 1920, "height": 1080},
+            "dumpio": True,
+            # "executablePath": "/root/.local/share/pyppeteer/local-chromium/588429/chrome-linux/chrome",
+            "args": ["--no-sandbox"]})
         page = await browser.newPage()
 
         await page.goto('https://www.oru.com/en/login')
+        sleep = 8000
+        _LOGGER.debug("Waiting for = %s millis", sleep)
+        await page.waitFor(sleep)
         # await page.screenshot({'path': 'oru0.png'})
 
         await page.type("#form-login-email", self.email)
@@ -73,16 +83,20 @@ class Meter(object):
         await page.click("#form-login-remember-me")
         await page.click(".submit-button")
         # Wait for login to authenticate
-        await page.waitFor(5000)
+        sleep = 20000
+        _LOGGER.debug("Waiting for = %s millis", sleep)
+        await page.waitFor(sleep)
         # await page.screenshot({'path': 'oru1.png'})
 
         # Enter in 2 factor auth code (see README for details)
-        await page.type("#form-login-mfa-code", self.mfa_aswer)
-        await page.screenshot({'path': 'oru2.png'})
+        await page.type("#form-login-mfa-code", self.mfa_answer)
+        # await page.screenshot({'path': 'oru2.png'})
         await page.click(".js-login-new-device-form .button")
         # Wait for authentication to complete
         await page.waitForNavigation()
-        await page.waitFor(5000)
+        sleep = 15000
+        _LOGGER.debug("Waiting for = %s millis", sleep)
+        await page.waitFor(sleep)
         # await page.screenshot({'path': 'oru2.1.png'})
 
         # Access the API using your newly acquired authentication cookies!
